==> ovirt-engine-reports-3.5.1.tar.gz: packaging/setup/plugins/ovirt-engine-common/ovirt-engine-reports/core/misc.py <==
#
# ovirt-engine-setup -- ovirt engine setup
# Copyright (C) 2013 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


import gettext
_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-reports')


from otopi import util
from otopi import plugin


from ovirt_engine_setup import constants as osetupcons
from ovirt_engine_setup.reports import constants as oreportscons


@util.export
class Plugin(plugin.PluginBase):

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_INIT,
    )
    def _init(self):
        self.environment.setdefault(oreportscons.CoreEnv.ENABLE, None)
        self.environment.setdefault(oreportscons.EngineCoreEnv.ENABLE, None)

    @plugin.event(
        stage=plugin.Stages.STAGE_SETUP,
    )
    def _setup(self):
        self.environment[
            osetupcons.CoreEnv.REGISTER_UNINSTALL_GROUPS
        ].createGroup(
            group='ovirt_reports_files',
            description='Reports files',
            optional=True,
        )
        self.environment[
            osetupcons.CoreEnv.SETUP_ATTRS_MODULES
        ].append(oreportscons)
        self.logger.debug(
            'reports version: %s-%s (%s)\n',
            oreportscons.Const.PACKAGE_NAME,
            oreportscons.Const.PACKAGE_VERSION,
            oreportscons.Const.DISPLAY_VERSION,
        )


# vim: expandtab tabstop=4 shiftwidth=4

==> ovirt-engine-reports-3.6.5.1.tar.gz: packaging/setup/plugins/ovirt-engine-common/ovirt-engine-reports/core/misc.py <==
#
# ovirt-engine-setup -- ovirt engine setup
# Copyright (C) 2013-2015 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


import gettext


from otopi import plugin
from otopi import util


from ovirt_engine_setup import constants as osetupcons
from ovirt_engine_setup.reports import constants as oreportscons


def _(m):
    return gettext.dgettext(message=m, domain='ovirt-engine-reports')


@util.export
class Plugin(plugin.PluginBase):

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_INIT,
    )
    def _init(self):
        self.environment.setdefault(oreportscons.CoreEnv.ENABLE, None)
        self.environment.setdefault(oreportscons.EngineCoreEnv.ENABLE, None)

    @plugin.event(
        stage=plugin.Stages.STAGE_SETUP,
    )
    def _setup(self):
        self.environment[
            osetupcons.CoreEnv.REGISTER_UNINSTALL_GROUPS
        ].createGroup(
            group='ovirt_reports_files',
            description='Reports files',
            optional=True,
        )
        self.environment[
            osetupcons.CoreEnv.SETUP_ATTRS_MODULES
        ].append(oreportscons)
        self.logger.debug(
            'reports version: %s-%s (%s)\n',
            oreportscons.Const.PACKAGE_NAME,
            oreportscons.Const.PACKAGE_VERSION,
            oreportscons.Const.DISPLAY_VERSION,
        )


# vim: expandtab tabstop=4 shiftwidth=4
